@@ -3,7 +3,7 @@
  */
 /*
     parted - a frontend to libparted
-    Copyright (C) 2006-2011 Free Software Foundation, Inc.
+    Copyright (C) 2006-2014, 2019-2021 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -135,7 +135,7 @@ void table_add_row (Table* t, wchar_t** row)
                 printf("[%s]", row[i]);
         putchar ('\n');*/
 
-        t->rows = xrealloc (t->rows, (t->nrows + 1) * sizeof(wchar_t***));
+        t->rows = xrealloc (t->rows, (t->nrows + 1) * sizeof(*(t->rows)));
 
         t->rows[t->nrows] = row;
 
